==> filezilla_3.2.7.2.orig.tar.gz: filezilla-3.2.7.2/src/interface/settings/optionspage.h <==
#ifndef __OPTIONSPAGE_H__
#define __OPTIONSPAGE_H__

#define SAFE_XRCCTRL(id, type) \
	if (!XRCCTRL(*this, id, type)) \
		return false; \
	XRCCTRL(*this, id, type)

class COptions;
class CSettingsDialog;
class COptionsPage : public wxPanel
{
public:
	bool CreatePage(COptions* pOptions, CSettingsDialog* pOwner, wxWindow* parent, wxSize& maxSize);

	virtual wxString GetResourceName() = 0;
	virtual bool LoadPage() = 0;
	virtual bool SavePage() = 0;
	virtual bool Validate() { return true; }

	void SetCheck(int id, bool checked, bool& failure);
	void SetCheckFromOption(int control_id, int option_id, bool& failure);
	void SetRCheck(int id, bool checked, bool& failure);
	void SetTextFromOption(int ctrlId, int optionId, bool& failure);
	void SetStaticText(int id, const wxString& text, bool& failure);
	void SetChoice(int id, int selection, bool& failure);

	// The GetXXX functions do never return an error since the controls were 
	// checked to exist while loading the dialog.
	bool GetCheck(int id);
	bool GetRCheck(int id);
	wxString GetText(int id);
	bool SetText(int id, const wxString& text, bool& failure);
	wxString GetStaticText(int id);
	int GetChoice(int id);

	void SetOptionFromText(int ctrlId, int optionId);
	void SetOptionFromCheck(int control_id, int option_id);

	void ReloadSettings();

	// Always returns false
	bool DisplayError(const wxString& controlToFocus, const wxString& error);
	bool DisplayError(wxWindow* pWnd, const wxString& error);

	bool Display();

	virtual bool OnDisplayedFirstTime();

protected:
	COptions* m_pOptions;
	CSettingsDialog* m_pOwner;

	bool m_was_selected;
};

#endif //__OPTIONSPAGE_H__

==> filezilla_3.3.1.orig.tar.gz: filezilla-3.3.1/src/interface/settings/optionspage.h <==
#ifndef __OPTIONSPAGE_H__
#define __OPTIONSPAGE_H__

#define SAFE_XRCCTRL(id, type) \
	if (!XRCCTRL(*this, id, type)) \
		return false; \
	XRCCTRL(*this, id, type)

class COptions;
class CSettingsDialog;
class COptionsPage : public wxPanel
{
public:
	bool CreatePage(COptions* pOptions, CSettingsDialog* pOwner, wxWindow* parent, wxSize& maxSize);

	virtual wxString GetResourceName() = 0;
	virtual bool LoadPage() = 0;
	virtual bool SavePage() = 0;
	virtual bool Validate() { return true; }

	void SetCheck(int id, bool checked, bool& failure);
	void SetCheckFromOption(int control_id, int option_id, bool& failure);
	void SetRCheck(int id, bool checked, bool& failure);
	void SetTextFromOption(int ctrlId, int optionId, bool& failure);
	void SetStaticText(int id, const wxString& text, bool& failure);
	void SetChoice(int id, int selection, bool& failure);

	// The GetXXX functions do never return an error since the controls were 
	// checked to exist while loading the dialog.
	bool GetCheck(int id);
	bool GetRCheck(int id);
	wxString GetText(int id);
	bool SetText(int id, const wxString& text, bool& failure);
	wxString GetStaticText(int id);
	int GetChoice(int id);

	void SetOptionFromText(int ctrlId, int optionId);
	void SetIntOptionFromText(int ctrlId, int optionId); // There's no corresponding GetTextFromIntOption as COptions::GetOption is smart enough to convert
	void SetOptionFromCheck(int control_id, int option_id);

	void ReloadSettings();

	// Always returns false
	bool DisplayError(const wxString& controlToFocus, const wxString& error);
	bool DisplayError(wxWindow* pWnd, const wxString& error);

	bool Display();

	virtual bool OnDisplayedFirstTime();

protected:
	COptions* m_pOptions;
	CSettingsDialog* m_pOwner;

	bool m_was_selected;
};

#endif //__OPTIONSPAGE_H__
